/*****************************************************************************
 * Copyright (C) 2014-2021
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of Brewery Management System
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/



function createDelElements() {
 $('#eventWindow').jqxWindow({
  theme: theme,
  position: { x: 490, y: 210 },
  width: 300,
  height: 175,
  resizable: false,
  isModal: true,
  modalOpacity: 0.4,
  okButton: $('#delOk'),
  cancelButton: $('#delCancel'),
  initContent: function() {
   $('#delOk').jqxButton({ template: 'danger', width: '65px', theme: theme });
   $('#delCancel').jqxButton({ template: 'success', width: '65px', theme: theme });
   $('#delCancel').focus();
  }
 });
 $('#eventWindow').jqxWindow('hide');
}



$(document).ready(function() {

 // tooltips
 $('#name').jqxTooltip({ content: 'De naam van de leverancier.' });
 $('#address').jqxTooltip({ content: 'Het adres en huisnummer.' });
 $('#city').jqxTooltip({ content: 'De woonplaats of gemeente.' });
 $('#zip').jqxTooltip({ content: 'De postcode.' });
 $('#country').jqxTooltip({ content: 'Het land.' });
 $('#website').jqxTooltip({ content: 'Het website adres.' });
 $('#email').jqxTooltip({ content: 'Het email adres.' });
 $('#phone').jqxTooltip({ content: 'Het telefoon nummer.' });
 $('#notes').jqxTooltip({ content: 'Opmerkingen over deze leverancier.' });

 var url = 'includes/db_inventory_suppliers.php',
 source = {
  datatype: 'json',
  cache: false,
  datafields: [
   { name: 'record', type: 'number' },
   { name: 'name', type: 'string' },
   { name: 'address', type: 'string' },
   { name: 'city', type: 'string' },
   { name: 'zip', type: 'string' },
   { name: 'country', type: 'string' },
   { name: 'website', type: 'string' },
   { name: 'email', type: 'string' },
   { name: 'phone', type: 'string' },
   { name: 'notes', type: 'string' }
  ],
  id: 'record',
  url: url,
  deleterow: function(rowid, commit) {
   // synchronize with the server - send delete command
   var data = 'delete=true&' + $.param({ record: rowid });
   $.ajax({
    dataType: 'json',
    url: url,
    cache: false,
    data: data,
    type: 'POST',
    success: function(data) {
     if (data.error) {
      console.log('delete: ' + data.msg);
      alert('Fout: ' + data.msg);
     } else {
      console.log('delete: success');
     }
     location.reload(true);
    },
    error: function(jqXHR, textStatus, errorThrown) {
     commit(false);
    }
   });
  },
  addrow: function(rowid, rowdata, position, commit) {
   var data = 'insert=true&' + $.param(rowdata);
   $.ajax({
    dataType: 'json',
    url: url,
    cache: false,
    data: data,
    type: 'POST',
    success: function(data) {
     if (data.error) {
      console.log('insert: ' + data.msg);
      alert('Fout: ' + data.msg);
     } else {
      console.log('insert: success');
     }
     location.reload(true);
    },
    error: function(jqXHR, textStatus, errorThrown) {
     commit(false);
    }
   });
  },
  updaterow: function(rowid, rowdata, commit) {
   var data = 'update=true&' + $.param(rowdata);
   $.ajax({
    dataType: 'json',
    url: url,
    cache: false,
    data: data,
    type: 'POST',
    success: function(data) {
     if (data.error) {
      console.log('updaterow: ' + data.msg);
      alert('Fout: ' + data.msg);
     } else {
      console.log('updaterow: success');
     }
     location.reload(true);
    },
    error: function(jqXHR, textStatus, errorThrown) {
     commit(false);
    }
   });
  }
 },
 dataAdapter = new $.jqx.dataAdapter(source),
        editrow = -1;

 // initialize the input fields.
 $('#name').jqxInput({ theme: theme, width: 640, height: 23 });
 $('#address').jqxInput({ theme: theme, width: 350, height: 23 });
 $('#zip').jqxInput({ theme: theme, width: 120, height: 23 });
 $('#city').jqxInput({ theme: theme, width: 350, height: 23 });
 $('#country').jqxInput({ theme: theme, width: 250, height: 23 });
 $('#website').jqxInput({ theme: theme, width: 640, height: 23 });
 $('#email').jqxInput({ theme: theme, width: 640, height: 23 });
 $('#phone').jqxInput({ theme: theme, width: 175, height: 23 });
 $('#notes').jqxInput({ theme: theme, width: 800, height: 100 });

 // initialize jqxGrid
 $('#jqxgrid').jqxGrid({
  width: 1280,
  height: 630,
  source: dataAdapter,
  theme: theme,
  showstatusbar: true,
  renderstatusbar: function(statusbar) {
   var rowCount = $("#jqxgrid").jqxGrid('getrows').length;
   statusbar.append('<div style="float: left; margin: 8px; color: orange !important;">Aantal items: ' + rowCount + '</div>');
   var addButton, container = $('<div style="overflow: hidden; position: relative; margin: 5px;"></div>');
   addButton = $('<div style="float: right; margin-right: 15px;"><img style="position: relative; margin-top: 2px;" ' +
     'src="images/add.png"/><span style="margin-left: 4px; position: relative; top: -3px;">Nieuw</span></div>');
   expButton = $('<div style="float: right; margin-right: 50px;"><img style="position: relative; margin-top: 2px;" ' +
     'src="images/database.png"/><span style="margin-left: 4px; position: relative; top: -3px;">Export</span></div>');
   container.append(addButton);
   container.append(expButton);
   statusbar.append(container);
   addButton.jqxButton({ theme: theme, width: 90, height: 20 });
   expButton.jqxButton({ theme: theme, width: 90, height: 20 });
   // add new row.
   addButton.click(function(event) {
    editrow = -1;
    $('#popupWindow').jqxWindow({ position: { x: 110, y: 30 } });
    $('#name').val('Nieuwe leverancier');
    $('#address').val('');
    $('#city').val('');
    $('#zip').val('');
    $('#country').val('Nederland');
    $('#website').val('');
    $('#email').val('');
    $('#phone').val('');
    $('#notes').val('');
    $('#popupWindow').jqxWindow('open');
   });
   expButton.click(function(event) {
    window.open('export_suppliers.php');
   });
  },
  filterable: false,
  columns: [
   { text: 'Leverancier naam', datafield: 'name' },
   { text: 'Adres', datafield: 'address', width: 300 },
   { text: 'Plaats', datafield: 'city', width: 250 },
   { text: 'Land', datafield: 'country', width: 200 },
   { text: 'Telefoon', datafield: 'phone', width: 175 },
   { text: 'Wijzig', datafield: 'Edit', width: 100, align: 'center', columntype: 'button',
    cellsrenderer: function() {
     return 'Wijzig';
    }, buttonclick: function(row) {
     // open the popup window when the user clicks a button.
     editrow = row;
     $('#popupWindow').jqxWindow({ position: { x: 110, y: 30 } });
     // get the clicked row's data and initialize the input fields.
     var dataRecord = $('#jqxgrid').jqxGrid('getrowdata', editrow);
     $('#name').val(dataRecord.name);
     $('#address').val(dataRecord.address);
     $('#city').val(dataRecord.city);
     $('#zip').val(dataRecord.zip);
     $('#country').val(dataRecord.country);
     $('#website').val(dataRecord.website);
     $('#email').val(dataRecord.email);
     $('#phone').val(dataRecord.phone);
     $('#notes').val(dataRecord.notes);
     // show the popup window.
     $('#popupWindow').jqxWindow('open');
    }
   }
  ]
 });
 // initialize the popup window and buttons.
 $('#popupWindow').jqxWindow({
  width: 1050,
  height: 550,
  resizable: false,
  theme: theme,
  isModal: true,
  autoOpen: false,
  cancelButton: $('#Cancel'),
  modalOpacity: 0.40
 });
 $('#popupWindow').on('open', function() {
  $('#name').jqxInput('selectAll');
 });
 $('#Delete').jqxButton({ template: 'danger', width: '90px', theme: theme });
 $('#Delete').click(function() {
  if (editrow >= 0) {
   // Open a popup to confirm this action.
   $('#eventWindow').jqxWindow('open');
   $('#delOk').click(function() {
    var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
    $('#jqxgrid').jqxGrid('deleterow', rowID);
   });
  }
  $('#popupWindow').jqxWindow('hide');
 });
 $('#Cancel').jqxButton({ template: 'primary', width: '90px', theme: theme });
 $('#Save').jqxButton({ template: 'success', width: '90px', theme: theme });
 // update the edited row when the user clicks the 'Save' button.
 $('#Save').click(function() {
  var row, rowID = -1;
  if (editrow >= 0) {
   rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
  }
  row = {
   record: rowID,
   name: $('#name').val(),
   address: $('#address').val(),
   city: $('#city').val(),
   zip: $('#zip').val(),
   country: $('#country').val(),
   website: $('#website').val(),
   email: $('#email').val(),
   phone: $('#phone').val(),
   notes: $('#notes').val()
  };
  if (editrow >= 0) {
   $('#jqxgrid').jqxGrid('updaterow', rowID, row);
  } else {
   $('#jqxgrid').jqxGrid('addrow', null, row);
  }
  $('#popupWindow').jqxWindow('hide');
 });
 createDelElements();
});

